
Changelog
=========

0.0.10 (2020-09-28)
-------------------

* fixed exception raising behaviour
* added unit tests
* renamed references to refer to 'cmd'
* updated travis-ci settings to use .com instead of .org site

0.0.9 (2020-09-28)
------------------

* added typing support
* build bug fixes.

0.0.8 (2020-09-26)
------------------

* build and deployment automation with travis.

0.0.7 (2020-09-26)
------------------

* trivial bug fixes

0.0.6 (2020-09-26)
------------------

* fixed basic case defect and added unit testing

0.0.5 (2020-09-26)
------------------

* fixed bugs in cli tool

0.0.4 (2020-09-26)
------------------

* updated supported, ssh-only and currently supported ssh cmds

0.0.3 (2020-09-25)
------------------

* fixed metavar issue with cli tool and added test coverage

0.0.2 (2020-09-25)
------------------

* first release on PyPI.
